<?php

namespace EasyVideoReviews;

defined('ABSPATH') or die('Direct Script not Allowed');

/** 
 * EVR Hook Class
 **/

if (!class_exists("\EasyVideoReviews\EVR_Hooks")) {

    final class EVR_Hooks

    {
        /**
         * Class instantiate 
         */

        static function init()
        {
            $instance = new self;
            $instance->register_hooks();
        }


        /**
         * Hooks Register
         */
        function register_hooks()
        {
            /**
             * Activation and Deactivation hooks
             */
            register_activation_hook(EVR_HANDLER_FILE, [$this, 'evr_activated']);
            register_deactivation_hook(EVR_HANDLER_FILE, [$this, 'plugin_deactivated']);


            /**
             * other hooks 
             */
            add_action("admin_menu", [$this, 'register_admin_menu']);
            add_action("admin_enqueue_scripts", [$this, 'register_evr_scripts_admin']);
            add_action("wp_enqueue_scripts", [$this, 'register_evr_scripts_frontend']);
            add_action("wp_footer", [$this, 'evr_add_script_wp_footer']);
            add_action("init", [$this, 'reset_evr_options']);
            add_action("init", [$this, 'add_evr_custom_shortcode']);
            // add_action("admin_init", [$this, 'activated_evr_safe_redirection']);
            add_action("template_redirect", [$this, 'evr_custom_single_video_page']);

            // custom blocks 
            add_action("elementor/widgets/widgets_registered", [$this, 'add_evr_elementor_widgets'], 99);

            // filters 
            add_filter("woocommerce_product_tabs", [$this, 'evr_woocommerce_product_tabs']);
            // triggers 
            add_action("woocommerce_thankyou", [$this, 'evr_woocommerce_thankyou'], 12);
            add_action("woocommerce_email_footer", [$this, 'evr_woocommerce_email_footer'], 12);
            add_action("edd_payment_receipt_after", [$this, 'evr_edd_add_review_button'], 12);
            add_action("edd_email_footer", [$this, 'evr_edd_email_footer'], 12);
            add_action("edd_after_download_content", [$this, 'evr_edd_after_download_content'], 12);

            add_action("admin_print_styles", [$this, 'add_styles_to_single_video_page']);
            add_action("admin_print_styles", [$this, 'add_styles_to_single_video_page']);
            add_action("admin_print_scripts", [$this, 'add_scripts_to_single_video_page']);

            add_action("plugin_action_links_" . plugin_basename(EVR_HANDLER_FILE), [$this, 'evr_plugin_action_links']);
            add_action("elementor/editor/before_enqueue_scripts", [$this, 'evr_elementor_before_enqueue_scripts']);
        }



        /**
         * After activation of EVR
         */

        function evr_activated()
        {
            $this->reset_evr_options();

            // add dynamic page 
            $recorder_page = maybe_serialize(get_option('evr_recorder_page'));
            if (empty($recorder_page)) {
                $post_details = array(
                    'post_title'    => __('Leave Video Review', 'easy-video-reviews'),
                    'post_content'  => '[evr-button]Leave a Review[/evr-button]',
                    'post_status'   => 'publish',
                    'post_author'   => 1,
                    'post_type' => 'page'
                );
                $page_id = wp_insert_post($post_details);
                update_option('evr_recorder_page', $page_id);
            }

            // Safe redirection 
            $this->activated_evr_safe_redirection();
        }

        /**
         * Redirection after activation 
         */
        function activated_evr_safe_redirection()
        {
            $redirected = get_option('evr_redirected', false);
            if (!$redirected) {
                update_option('evr_redirected', true);
                wp_redirect(admin_url('admin.php?page=evr-admin#subscription'));
                exit();
            }
        }


        /**
         * Plugin deactivatin hook
         */
        function plugin_deactivated()
        {
            // delete authentication token 
            delete_option('evr_token');
        }


        /**
         * Enqueuing scripts for backend
         */
        function register_evr_scripts_admin()
        {

            $args_pages = array(
                'sort_order' => 'asc',
                'sort_column' => 'post_title',
                'hierarchical' => 1,
                'post_type' => 'page',
                'post_status' => 'publish',
                'posts_per_page' => -1
            );
            $pages = get_pages($args_pages);
            $allpages = [];
            foreach ($pages as $page) {
                $allpages[] = (object) [
                    'id' => esc_html($page->ID),
                    'title' => !empty($page->post_title) ? esc_html($page->post_title) : 'Untitled Page',
                    'slug' => esc_html($page->post_name),
                ];
            }


            $admin_footer_script = [
                "ajaxurl" => admin_url('admin-ajax.php'),
                "sass" => esc_url(EVR_SASS_BASE_URL),
                "plugin_url" => plugin_dir_url(EVR_HANDLER_FILE),
                "home_url" => home_url(),
                "wrat" => get_option('evr_token'),
                "woocommerce" => (bool) class_exists('\WooCommerce'),
                "edd" => (bool) class_exists('\Easy_Digital_Downloads'),
                "pages" => $allpages
            ];
            wp_register_script('evr_object_scripts', '');
            wp_localize_script('evr_object_scripts', 'evr_object', $admin_footer_script);
            wp_enqueue_script('evr_object_scripts');
            wp_enqueue_script('evr-vue', plugin_dir_url(EVR_HANDLER_FILE) . 'public/js/vue.global.prod.js', ['jquery'], filemtime(plugin_dir_path(EVR_HANDLER_FILE) . 'public/js/vue.global.prod.js'), true);
            wp_enqueue_script('evr-admin', plugin_dir_url(EVR_HANDLER_FILE) . 'public/js/admin.js', ['jquery'], filemtime(plugin_dir_path(EVR_HANDLER_FILE) . 'public/js/admin.js'), true);
            wp_enqueue_style('dashicons');
            wp_enqueue_style('evr-admin', plugin_dir_url(EVR_HANDLER_FILE) . 'public/css/admin.css');
        }

        /**
         * Enqueuing scripts for frontend
         */

        function register_evr_scripts_frontend()
        {

            $recorder =  get_evr_option('recorder');
            $forms = get_evr_option('forms');
            $translations = get_evr_option('translations');

            $frontend_footer_script = [
                "sass" => esc_url(EVR_SASS_BASE_URL),
                "ajaxurl" => esc_url(
                    admin_url('admin-ajax.php')),
                "home_url" => esc_url(home_url()),
                "wrat" => esc_html(get_option('evr_token')),
                "preference" => $recorder,
                "forms" => $forms,
                "translations" => $translations,
                "ip" => $this->getUserIP()
            ];
            wp_register_script('evr_options_scripts', '');
            wp_localize_script('evr_options_scripts', 'evr_options', $frontend_footer_script);
            wp_enqueue_script('evr_options_scripts');

            wp_enqueue_script('evr-vue', plugin_dir_url(EVR_HANDLER_FILE) . 'public/js/vue.global.prod.js', ['jquery'], filemtime(plugin_dir_path(EVR_HANDLER_FILE) . 'public/js/vue.global.prod.js'), true);
            wp_enqueue_script('evr-frontend', plugin_dir_url(EVR_HANDLER_FILE) . 'public/js/frontend.js', ['jquery'], filemtime(plugin_dir_path(EVR_HANDLER_FILE) . 'public/js/frontend.js'), true);
            wp_enqueue_style('evr-frontend', plugin_dir_url(EVR_HANDLER_FILE) . 'public/css/frontend.css');
        }

        /**
         * Admin menu page 
         */

        function register_admin_menu()
        {
            global $token;
            $token = get_option('evr_token');

            add_menu_page((!$token ? 'Get Started With ' : '') . __('Easy Video Reviews', 'easy-video-reviews'), __('Easy Video Reviews', 'easy-video-reviews'), 'edit_posts', 'evr-admin', function () {

                global $token;

                $page_to_load = "get-started";

                if ($token && !empty($token)) {
                    $page_to_load = "admin-dashboard";
                }

                include_once plugin_dir_path(EVR_HANDLER_FILE) . 'templates/' . $page_to_load . '.php';
            }, plugin_dir_url(EVR_HANDLER_FILE) . 'public/images/icon.png', 99);
        }

        /**
         * Scripts on Frontend Footer
         */
        function evr_add_script_wp_footer()

        {
            /**
             * load the recorder element 
             */
            include_once plugin_dir_path(EVR_HANDLER_FILE) . 'templates/frontend-recorder.php';
        }


        /**
         * Translations
         */
        function getTranslations()
        {
            $texts = [
                'Upload Review',
                'Record Review',
                'You can record up to %s minutes, don\'t worry you will review your video before sending',
                'Hide Options',
                'Show Options',
                'Delay',
                'No Delay',
                'Front',
                'Back',
                'Immediate',
                'Seconds',
                'Choose Camera',
                'Default Camera',
                'Choose Microphone',
                'Default Microphone',
                'Looks Good, Continue',
                'Upload Video',
                'Uploading Video',
                'Record New Video',
                'I\'m allowing to publish this video',
                'Submit',
                'Record',
                'Continue',
                'Record Video',
                'Start Over',
                'Drag your files here or click in this area',
                'You have no camera installed on your device'
            ];

            $newArray = [];
            foreach ($texts as $text) {
                $newArray[$text] = $text;
            }

            return apply_filters('evr_translations', $newArray);
        }



        /**
         * Get EVR Registered Options 
         */

        function get_evr_options()
        {
            $options = [
                'recorder' => [
                    'limits' => 60,
                    'upload' => false,
                    'publish_policy' => false,
                    'show_options' => false,
                    'form' => false,
                    'delay' => 3,
                ],
                'recorder_page' => '',
                'email' => [
                    'message' => "If you like the product, please leave a video review for us {button}",
                    'button' => [
                        'text' => 'Leave a video review',
                        'style' => 'blue',
                    ],
                    'url' => [
                        'label' => 'Leave a video review'
                    ]
                ],
                'button' => [
                    'text' => 'Leave a video review',
                    'style' => 'blue',
                    'size' => '',
                    'alignment' => 'center'
                ],
                'woocommerce' => [
                    'order_complete' => [
                        'button' => false,
                        'email' => false,
                    ],
                    'single_product' => [
                        'button' => false,
                        'showcase' => [
                            'show' => false,
                            'limit' => 5
                        ]
                    ],

                ],
                'edd' => [
                    'order_complete' => [
                        'button' => false,
                        'email' => false,
                    ],
                    'single_product' => [
                        'button' => false,
                        'showcase' => [
                            'show' => false,
                            'limit' => 5
                        ]
                    ],

                ],
                'optimization' => [
                    'showcase' =>  [
                        'title' => 'Video Review',
                        'description' => esc_html(get_bloginfo('description')),
                        'slug' => 'video-review',
                    ],
                    'social' => [
                        'facebook' => ['show' => false, 'id' => ''],
                        'twitter' => ['show' => false, 'username' => ''],
                    ]
                ],
                'forms' => [],
                'translations' => $this->getTranslations()
            ];

            return apply_filters('evr_plugin_options', $options);
        }


        /**
         * Reset EVR Plugin Options to default
         */
        function reset_evr_options($delete = false)
        {
            $options = $this->get_evr_options();
            foreach ($options as $key => $value) {
                if ($delete)
                    delete_option('evr_' . $key, true);
                add_option('evr_' . $key, maybe_serialize($value));
            }
        }

        /**
         * Current user IP address
         */
        function getUserIP()
        {
            $ipaddress = '';
            if (isset($_SERVER['HTTP_CLIENT_IP']))
                $ipaddress = $_SERVER['HTTP_CLIENT_IP'];
            else if (isset($_SERVER['HTTP_X_FORWARDED_FOR']))
                $ipaddress = $_SERVER['HTTP_X_FORWARDED_FOR'];
            else if (isset($_SERVER['HTTP_X_FORWARDED']))
                $ipaddress = $_SERVER['HTTP_X_FORWARDED'];
            else if (isset($_SERVER['HTTP_X_CLUSTER_CLIENT_IP']))
                $ipaddress = $_SERVER['HTTP_X_CLUSTER_CLIENT_IP'];
            else if (isset($_SERVER['HTTP_FORWARDED_FOR']))
                $ipaddress = $_SERVER['HTTP_FORWARDED_FOR'];
            else if (isset($_SERVER['HTTP_FORWARDED']))
                $ipaddress = $_SERVER['HTTP_FORWARDED'];
            else if (isset($_SERVER['REMOTE_ADDR']))
                $ipaddress = $_SERVER['REMOTE_ADDR'];
            else
                $ipaddress = 'UNKNOWN';
            return $ipaddress;
        }

        /**
         * Load Elementor Widget
         */

        function add_evr_elementor_widgets()
        {
            require_once __DIR__ . '/../elementor/elementor-buttons.php';
            require_once __DIR__ . '/../elementor/elementor-showcase.php';
            \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new \EasyVideoReviews\EVR_ElementorButtons());
            \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new \EasyVideoReviews\EVR_ElementorShowcase());
        }


        /**
         * On WooCommerce Single Product Tabs
         */

        function evr_woocommerce_product_tabs($tabs)
        {
            $woocommerce_option = get_evr_option('woocommerce');
            if ($woocommerce_option->single_product->button || $woocommerce_option->single_product->showcase) {
                $tabs['video_testimonials'] = array(
                    'title'     => __('Video Testimonials', 'easy-video-reviews'),
                    'priority'     => 50,
                    'callback'     => [$this, 'evr_custom_data_tab_callback']
                );
            }

            return $tabs;
        }


        /**
         * WooCommerce Single Product Tabs Callback Function
         */

        function evr_custom_data_tab_callback()
        {
            global $product;
            $tag = esc_atts("prouct-" . $product->id());

            $woocommerce_option = get_eavr_option('woocommerce');
            $button = get_evr_option('button');
            echo ('<div class="woocommerce">');
            if ($woocommerce_option->single_product->button) {
                echo wp_kses_post(do_shortcode('[evr-button tag=' . $tag . ']'));
            }
            if ($woocommerce_option->single_product->showcase->show) {
                echo wp_kses_post(do_shortcode('[evr-videos limit=' . esc_attr($woocommerce_option->single_product->showcase->limit) . ' tag=' . $tag . ']'));
            }
            echo '</div>';
        }


        /**
         * On WooCommerce Thank you Page
         */

        function evr_woocommerce_thankyou($order_id)
        {
            $woocommerce_option = get_evr_option('woocommerce');
            if (!$woocommerce_option->order_complete->button) return false; 
            echo wp_kses_post(do_shortcode('[evr-button tag=' . esc_attr('order-' . $order_id) . ']'));
        }

        function evr_edd_after_download_content()
        {
            // do nothing
        }



        /**
         * Custom Shortcodes
         */

        function add_evr_custom_shortcode()
        {
            add_shortcode('evr-button', function ($atts, $content) { {

                    $button = get_evr_option('button');

                    $atts = shortcode_atts(array(
                        'size' => $button->size,
                        'color' => $button->style,
                        'align' => $button->style,
                        'tag' => 'general',
                    ), $atts, 'evr-button');

                    $tag = sanitize_text_field($_REQUEST['tag']);
                    $tag = empty($tag) ? $atts['tag'] : $tag;
                    $content2 = sanitize_text_field($_REQUEST['button']);
                    $content = empty($content2) ? $content : $content2;
                    $out = "<div class='my-4 text-{$atts['align']}'><a href='javascript:;' class='text-{$atts['size']} transition duration-100 py-2 px-4 rounded-sm bg-{$atts['color']}-400 hover:bg-{$atts['color']}-500 text-white hover:text-white focus:text-white' data-evr-button='{$tag}'>{$content}</a></div>";
                    return $out;
                }
            });

            add_shortcode('evr-videos', function ($atts, $content = null) { {
                    $atts = shortcode_atts(array(
                        'limit' => 10,
                        'view' => 'grid',
                        'cols' => 2,
                        'tag' => 'general',
                        'id' => '',
                    ), $atts, 'evr-videos');


                    $configs = [
                        'limit' => esc_attr($atts['limit']),
                        'order' => esc_attr($atts['order']),
                        'tag' => esc_attr($atts['tag']),
                    ];

                    $showcase = "";

                    if ($atts['view'] == 'slider') {

                        $showcase = "<div class=\"swiper-container evr-swiper\">
                <div class=\"swiper-wrapper\" data-evr-videos='" . wp_json_encode($configs) . "'\">
                    <div class=\"swiper-slide\">
                        <div class=\"swiper-lazy-preloader\"></div>
                    </div>
                </div>
                <div class=\"swiper-pagination\"></div>
                <div class=\"swiper-button-next w-4 h-4\"></div>
                <div class=\"swiper-button-prev w-4 h-4\"></div>
            </div>";
                    } else {

                        $showcase = "<div class=\"grid grid-cols-1 xs:grid-cols-2  gap-2 md:gap-3 lg:gap-4\" data-evr-videos='" . wp_json_encode($configs) . "'\">
                <div class=\"swiper-lazy-preloader\"></div></div>";
                    }


                    return $showcase;
                }
            });
        }



        /**
         * Single page video page / player
         */

        function evr_custom_single_video_page()
        {
            global $wp_query;
            $optimization = get_evr_option('optimization');

            $query_page_name = $wp_query->query['name'] ?? $wp_query->query['pagename'];
            // var_dump($optimization->showcase->slug);
            if ($query_page_name != ($optimization->showcase->slug ?? 'video-review')) return false;
            include_once plugin_dir_path(EVR_HANDLER_FILE) . 'templates/single-review-page.php';
            exit();
        }



        /**
         * On WooCommerce Thank you Page
         */

        function build_dynamic_message($pre_text = '', $args = [])
        {

            $output = $pre_text;

            if ($args && !empty($args)) {
                foreach ($args as $arg => $value) {
                    $output = preg_replace("/\{$arg\}/i", $value, $output);;
                }
            }

            return $output;
        }



        /**
         * Email message
         */

        function getEmailAppendMessage()
        {
            $email = get_evr_option('email');
            $recorder_page = get_evr_option('recorder_page');

            $url = get_permalink($recorder_page) . '?tag=orders&source=email';
            $url_label = !empty($email->url->label) ? $email->url->label : $url;

            $message = $this->build_dynamic_message("<div class=\"text-center\">{$email->message}</div>", [
                'button' => "<div style=\"text-align:center; padding: 6px 0\">
            <a href=\"{$url}\" target=\"_blank\" style=\"display: block; background: {$email->button->style}; color: #fff; padding: 7px 15px; border-radius: 5px;\" evr-open=\"orders\">
                {$email->button->text}
            </a>
        </div>",
                'url' => "<a href=\"{$url}\">{$url_label}</a>"
            ]);
            return apply_filters('evr_thankyou_email_html', $message);
        }



        /**
         * WooCommerce Email footer
         */

        function evr_woocommerce_email_footer($email)
        {
            if ($email->id != 'customer_completed_order') return false;
            $woocommerce_option = get_evr_option('woocommerce');
            if (!$woocommerce_option->order_complete->email) return false;

            echo wp_kses_post($this->getEmailAppendMessage());
        }



        /**
         * Easy Digital Downloads Button after purchasing
         */

        function evr_edd_add_review_button()
        {
            $edd_option = get_evr_option('edd');

            if (!$edd_option->order_complete->button) return false;
            $button = get_evr_option('button');
            echo wp_kses_post(do_shortcode('[evr-button tag="edd-review"]'));
        }



        /**
         * Easy Digital Downloads Email Footer
         */
        function evr_edd_email_footer()
        {
            $edd_option = get_evr_option('edd');
            if (!$edd_option->order_complete->email) return false;

            echo wp_kses_post($this->getEmailAppendMessage());
        }




        /**
         * Single Video Page Styles
         */
        function add_styles_to_single_video_page()
        {
            if (!is_admin()) {
                wp_enqueue_style('evr_single_style', plugin_dir_url(EVR_HANDLER_FILE) . "public/css/frontend.css", [], null, false);
            }
        }




        /**
         * Single Video Page Scripts
         */

        function add_scripts_to_single_video_page()
        {
            if (!is_admin()) {
                wp_enqueue_script('jquery');
                wp_enqueue_script('evr_single_script', plugin_dir_url(EVR_HANDLER_FILE) . "public/js/frontend.js", [], null, false);
            }
        }


        /**
         * Custom Plugin Action Link
         */
        function evr_plugin_action_links($links)
        {
            $url = add_query_arg('page', 'evr-admin/#reviews', get_admin_url() . 'admin.php');

            // Create the link and escape .
            $setting_link = '<a href="' . esc_url($url) . '">' . __('Video Reviews', 'easy-video-reviews') . '</a>';

            // Adds the link to the end of the array.
            array_unshift($links, wp_kses_post($setting_link));

            return $links;
        }



        /**
         * Elementor before scripts add custom icon class 
         */
        function evr_elementor_before_enqueue_scripts()
        {
            echo '<style>';
            echo '
.evr-logo-icon {
  width: 25px;
height: 20px;
display: inline-block;
margin: auto;
  background-image: url(\'' . plugin_dir_url(EVR_HANDLER_FILE) . 'public/images/evr.svg\') !important;
  background-size: 100%;
}';
            echo '</style>';
        }
    }
}
