<?php

namespace EasyVideoReviews;

if (!defined('ABSPATH')) exit; 

/**
 * Elementor Widget Class
 */


if (!class_exists('\EasyVideoReviews\EVR_ElementorButtons')) {

    class EVR_ElementorButtons extends \Elementor\Widget_Base

    {

        public function get_name()
        {
            return 'evr-buttons';
        }

        public function get_title()
        {
            return __('Easy Video Reviews Button', 'easy-video-reviews');
        }

        public function get_icon()
        {
            return 'evr-logo-icon';
        }

        public function get_categories()
        {
            return ['general'];
        }

        protected function _register_controls()
        {

            $this->start_controls_section(
                'section_content',
                [
                    'label' => __('Button', 'easy-video-reviews'),
                ]
            );

            $this->add_control(
                'button_label',
                [
                    'label' => __('Button Label', 'easy-video-reviews'),
                    'type' => 'text',
                    'default' => 'Record Review'
                ]
            );
            $this->add_control(
                'tag',
                [
                    'label' => __('Recording Tag', 'easy-video-reviews'),
                    'type' => 'text',
                    'default' => 'general'
                ]
            );
            $this->add_control(
                'button_style',
                [
                    'label' => __('Button Style', 'easy-video-reviews'),
                    'type' => 'select',
                    'options' => [
                        'blue' => __('Blue', 'easy-video-reviews'),
                        'red' => __('Red', 'easy-video-reviews'),
                        'green' => __('Green', 'easy-video-reviews'),
                        'indigo' => __('Indigo', 'easy-video-reviews'),
                        'yellow' => __('Yellow', 'easy-video-reviews'),
                        'pink' => __('Pink', 'easy-video-reviews'),
                    ],
                    'default' => 'blue',
                ]
            );

            $this->add_control(
                'button_size',
                [
                    'label' => __('Button Size', 'easy-video-reviews'),
                    'type' => 'select',
                    'options' => [
                        '4xl' => __('Extra Extra Large', 'easy-video-reviews'),
                        '2xl' => __('Extra Large', 'easy-video-reviews'),
                        'md' => __('Medium', 'easy-video-reviews'),
                        'lg' => __('Normal', 'easy-video-reviews'),
                        'sm' => __('Small', 'easy-video-reviews'),
                        'xs' => __('Extra Small', 'easy-video-reviews'),
                    ],
                    'default' => 'md',
                ]
            );

            $this->add_control(
                'button_alignment',
                [
                    'label' => __('Button Alignment', 'easy-video-reviews'),
                    'type' => 'choose',
                    'options' => [
                        'left' => [
                            'title' => __('Left', 'easy-video-reviews'),
                            'icon' => 'fa fa-align-left',
                        ],
                        'center' => [
                            'title' => __('Center', 'easy-video-reviews'),
                            'icon' => 'fa fa-align-center',
                        ],
                        'right' => [
                            'title' => __('Right', 'easy-video-reviews'),
                            'icon' => 'fa fa-align-right',
                        ],
                    ],
                    'default' => 'center',
                ]
            );

            $this->end_controls_section();
        }


        protected function render()
        {
            $settings = $this->get_settings_for_display();

            $this->add_inline_editing_attributes('label', 'basic');

            $button = '[evr-button align=' . esc_attr($settings['button_alignment']) . ' size' . esc_attr($settings['button_size']) . ' color=' . esc_html($settings['button_style']) . ' tag=' . esc_attr($settings['tag']) . ']' . esc_html($settings['button_label']) . '[/evr-button]';
            
            echo (is_admin()) ? wp_kses_post(do_shortcode($button)) : wp_kses_post($button);
        }
    }
}
