<?php
global $wp_query;
status_header(200);

$video_id = sanitize_text_field($_REQUEST['id']);
$headless = (bool) sanitize_text_field($_REQUEST['headless']);

$video = \EasyVideoReviews\EVR_SingleVideo::init($video_id);


$optimization = maybe_unserialize(get_option('evr_optimization'));

$page_url = home_url($optimization->showcase->slug . '/?id=' . sanitize_text_field($video->response->short));


$title = (!empty($video) ? $optimization->showcase->title : 'Invalid Video Request') . ' &raquo; ' .  $optimization->showcase->description;

?>
<!DOCTYPE html>
<html lang="en">

<head>
  <meta charset="UTF-8">
  <meta http-equiv="X-UA-Compatible" content="IE=edge">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <title><?php echo esc_html($title); ?></title>
  <link rel="shortcut icon" href="<?php echo esc_url(get_site_icon_url()); ?>" type="image/x-icon">
  <?php

  // load scripts 
  do_action('admin_print_styles');

  ?>

  <?php if ($optimization->social->facebook->show) : ?>
    <meta property="fb:app_id" content="<?php echo esc_html($single_page->facebook_id); ?>">
    <meta property="og:url" content="<?php echo esc_html($page_url); ?>">
    <meta property="og:title" content="<?php echo esc_html($title); ?>">
    <meta property="og:description" content="<?php echo esc_html($single_page->description); ?>">
    <meta property="og:type" content="video">
    <meta property="og:image" content="<?php echo esc_html($video->thumbnail); ?>">
    <meta property="og:video" content="<?php echo esc_html($video->response->url); ?>">
    <meta property="og:video:type" content="video/webm">
    <meta property="og:video:width" content="400">
    <meta property="og:video:height" content="600">
    <meta property="og:site_name" content="<?php bloginfo('name') ?>">
  <?php endif; ?>


  <?php if ($optimization->social->twitter->show) : ?>
    <meta name="twitter:card" content="<?php echo esc_html($video->response->thumbnail); ?>" />
    <meta name="twitter:title" content="<?php echo esc_html($title); ?>" />
    <meta name="twitter:description" content="<?php echo esc_html($optimization->social->twitter->username); ?>" />
    <meta name="twitter:site" content="@<?php echo esc_html($single_page->twitter_username); ?>" />
    <meta name="twitter:image" content="<?php echo esc_html($video->response->thumbnail); ?>" />
    <meta name="twitter:creator" content="@<?php echo esc_html($optimization->social->twitter->username); ?>" />
  <?php endif; ?>


</head>

<body>

  <?php if ($video->response && !empty($video->response)) : ?>

    <div class="w-full overflow-hidden <?php echo !$headless ? 'p-3' : ''; ?>">
      <div class="bg-gray-100 rounded-md evr-testimonial <?php echo !$headless ? 'max-w-screen-lg mx-auto' : ''; ?> w-full">
        <video class="z-50 w-full cursor-pointer rounded-sm" controls="" src="<?php echo esc_url($video->response->url); ?>"></video>

        <div class="py-3 px-4 text-gray-400 text-sm flex items-center justify-between">
          <div class=""><?php echo esc_html($video->response->ago) ?></div>
          <div class="evr-social-share relative inline-flex justify-center items-center">

            <div class="evr-social-share-button opacity-0 flex items-center">
              <a href="https://www.facebook.com/sharer/sharer.php?u=<?php echo esc_url(urldecode($page_url)); ?>" class="sharer flex items-center justify-center h-8 w-8 rounded-full bg-blue-500 mr-2 text-white hover:text-white -top-14 left-4 cursor-pointer">
                <svg xmlns="http://www.w3.org/2000/svg" class="fill-current h-4 w-4" viewBox="0 0 24 24">
                  <path d="M9 8h-3v4h3v12h5v-12h3.642l.358-4h-4v-1.667c0-.955.192-1.333 1.115-1.333h2.885v-5h-3.808c-3.596 0-5.192 1.583-5.192 4.615v3.385z" />
                </svg>
              </a>
              <a href="http://twitter.com/share?text=Video Testimonial&url=<?php echo esc_url(urldecode($page_url)); ?>" class="sharer flex items-center justify-center h-8 w-8 rounded-full bg-blue-400 mr-2 text-white hover:text-white -top-4 left-8 cursor-pointer">
                <svg xmlns="http://www.w3.org/2000/svg" class="fill-current h-4 w-4" viewBox="0 0 24 24">
                  <path d="M24 4.557c-.883.392-1.832.656-2.828.775 1.017-.609 1.798-1.574 2.165-2.724-.951.564-2.005.974-3.127 1.195-.897-.957-2.178-1.555-3.594-1.555-3.179 0-5.515 2.966-4.797 6.045-4.091-.205-7.719-2.165-10.148-5.144-1.29 2.213-.669 5.108 1.523 6.574-.806-.026-1.566-.247-2.229-.616-.054 2.281 1.581 4.415 3.949 4.89-.693.188-1.452.232-2.224.084.626 1.956 2.444 3.379 4.6 3.419-2.07 1.623-4.678 2.348-7.29 2.04 2.179 1.397 4.768 2.212 7.548 2.212 9.142 0 14.307-7.721 13.995-14.646.962-.695 1.797-1.562 2.457-2.549z" />
                </svg>
              </a>
              <a href="https://www.linkedin.com/sharing/share-offsite/?url=<?php echo esc_url(home_url('video/?id=' . $video->response->short)); ?>" class="sharer flex items-center justify-center h-8 w-8 rounded-full bg-blue-500 mr-2 text-white hover:text-white top-6 left-4 cursor-pointer">
                <svg xmlns="http://www.w3.org/2000/svg" class="fill-current h-4 w-4" viewBox="0 0 24 24">
                  <path d="M4.98 3.5c0 1.381-1.11 2.5-2.48 2.5s-2.48-1.119-2.48-2.5c0-1.38 1.11-2.5 2.48-2.5s2.48 1.12 2.48 2.5zm.02 4.5h-5v16h5v-16zm7.982 0h-4.968v16h4.969v-8.399c0-4.67 6.029-5.052 6.029 0v8.399h4.988v-10.131c0-7.88-8.922-7.593-11.018-3.714v-2.155z" />
                </svg>
              </a>
              <a href="http://pinterest.com/pin/create/link/?url=${sass}video/?id=<?php echo esc_url(urldecode($page_url)); ?>" class="sharer flex items-center justify-center h-8 w-8 rounded-full bg-red-500 mr-2 text-white hover:text-white -top-14 left-14 cursor-pointer">
                <svg xmlns="http://www.w3.org/2000/svg" class="fill-current h-4 w-4" viewBox="0 0 24 24">
                  <path d="M12 0c-6.627 0-12 5.372-12 12 0 5.084 3.163 9.426 7.627 11.174-.105-.949-.2-2.405.042-3.441.218-.937 1.407-5.965 1.407-5.965s-.359-.719-.359-1.782c0-1.668.967-2.914 2.171-2.914 1.023 0 1.518.769 1.518 1.69 0 1.029-.655 2.568-.994 3.995-.283 1.194.599 2.169 1.777 2.169 2.133 0 3.772-2.249 3.772-5.495 0-2.873-2.064-4.882-5.012-4.882-3.414 0-5.418 2.561-5.418 5.207 0 1.031.397 2.138.893 2.738.098.119.112.224.083.345l-.333 1.36c-.053.22-.174.267-.402.161-1.499-.698-2.436-2.889-2.436-4.649 0-3.785 2.75-7.262 7.929-7.262 4.163 0 7.398 2.967 7.398 6.931 0 4.136-2.607 7.464-6.227 7.464-1.216 0-2.359-.631-2.75-1.378l-.748 2.853c-.271 1.043-1.002 2.35-1.492 3.146 1.124.347 2.317.535 3.554.535 6.627 0 12-5.373 12-12 0-6.628-5.373-12-12-12z" fill-rule="evenodd" clip-rule="evenodd" />
                </svg>
              </a>

            </div>
            <a class="text-right evr-social-share-toggler bg-blue-400 hover:bg-blue-500 text-white hover:text-white px-2 py-2 rounded-full cursor-pointer flex items-center justify-center focus:outline-none">
              <svg xmlns="http://www.w3.org/2000/svg" class="fill-current h-4 w-4" viewBox="0 0 24 24">
                <path d="M20 3c0-1.657-1.344-3-3-3s-3 1.343-3 3c0 .312.061.606.149.889l-4.21 3.157c.473.471.878 1.01 1.201 1.599l4.197-3.148c.477.316 1.048.503 1.663.503 1.656 0 3-1.343 3-3zm-2 0c0 .551-.448 1-1 1s-1-.449-1-1 .448-1 1-1 1 .449 1 1zm3 12.062c1.656 0 3-1.343 3-3s-1.344-3-3-3c-1.281 0-2.367.807-2.797 1.938h-6.283c.047.328.08.66.08 1s-.033.672-.08 1h6.244c.396 1.195 1.509 2.062 2.836 2.062zm-1-3c0-.551.448-1 1-1s1 .449 1 1-.448 1-1 1-1-.448-1-1zm-20-.062c0 2.761 2.238 5 5 5s5-2.239 5-5-2.238-5-5-5-5 2.239-5 5zm2 0c0-1.654 1.346-3 3-3s3 1.346 3 3-1.346 3-3 3-3-1.346-3-3zm7.939 4.955l4.21 3.157c-.088.282-.149.576-.149.888 0 1.657 1.344 3 3 3s3-1.343 3-3-1.344-3-3-3c-.615 0-1.186.187-1.662.504l-4.197-3.148c-.324.589-.729 1.127-1.202 1.599zm6.061 4.045c0-.551.448-1 1-1s1 .449 1 1-.448 1-1 1-1-.449-1-1z" />
              </svg>
            </a>

          </div>
        </div>
      </div>


    </div>

  <?php else :

    status_header(404);
    
  ?>
    <div class="py-4 px-4 tracking-wider text-center bg-red-100 text-red-600 rounded-md"><?php echo esc_html__('Invalid Video Request', 'easy-video-reviews'); ?></div>
  <?php endif; ?>

  <?php

  // load scripts 
  do_action('admin_print_scripts');

  ?>
</body>

</html>